@@ -63,7 +63,7 @@
 template <typename T> inline void unused(const T &, ...) {}
 
 #ifdef _TIMING_ENABLED_
-#define TIMING TimeLogger::getInstance()->step(__PRETTY_FUNCTION__, __LINE__, __FILE__)
+#define TIMING GmicQt::TimeLogger::getInstance()->step(__PRETTY_FUNCTION__, __LINE__, __FILE__)
 #else
 #define TIMING                                                                                                                                                                                         \
   if (false)                                                                                                                                                                                           \
