@@ -28,6 +28,7 @@
 #include <QGridLayout>
 #include <QLabel>
 #include <QPalette>
+#include <QRandomGenerator>
 #include <QWidget>
 #include "Common.h"
 #include "FilterTextTranslator.h"
@@ -89,7 +90,9 @@ void BoolParameter::setValue(const QString & value)
 {
   _value = (value == "1");
   if (_checkBox) {
+    disconnectCheckBox();
     _checkBox->setChecked(_value);
+    connectCheckBox();
   }
 }
 
@@ -99,6 +102,16 @@ void BoolParameter::reset()
   _value = _default;
 }
 
+void BoolParameter::randomize()
+{
+  if (acceptRandom()) {
+    _value = QRandomGenerator::global()->bounded(0, 2);
+    disconnectCheckBox();
+    _checkBox->setChecked(_value);
+    connectCheckBox();
+  }
+}
+
 void BoolParameter::onCheckBoxChanged(bool on)
 {
   _value = on;
